
-------------------------------------------------------------------------------
-- Optimization
-------------------------------------------------------------------------------

local C_SocialQueue = C_SocialQueue
local next = next
local SocialQueueUtil_GetRelationshipInfo = SocialQueueUtil_GetRelationshipInfo

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local L = LibStub:GetLibrary("SixSocial-1.0", true)
if not L then return end

local groups = {}

-------------------------------------------------------------------------------
-- Helpers
-------------------------------------------------------------------------------

local function ProcessGroupMember(groupGUID, member)
	local name = SocialQueueUtil_GetRelationshipInfo(member.guid, nil, member.clubId)

	if member.guid and member.guid ~= "" then
		groups[member.guid] = groupGUID
	end

	if name and name ~= "" then
		groups[name] = groupGUID
	end
end

local function ProcessGroupMembers(groupGUID, members)
	if members then
		for _, member in next, members do
			ProcessGroupMember(groupGUID, member)
		end
	end
end

local function ProcessGroup(groupGUID)
	if C_SocialQueue.GetGroupInfo(groupGUID) then
		ProcessGroupMembers(groupGUID, C_SocialQueue.GetGroupMembers(groupGUID))
	end
end

-------------------------------------------------------------------------------
-- Library
-------------------------------------------------------------------------------

function L:GetGroupGuid(...)
	for _, name in next, {...} do
		if groups[name] then
			return groups[name]
		end
	end
end

function L:UpdateGroups()
	if (not C_SocialQueue) then return end

	groups = {}

	for _, groupGUID in next, C_SocialQueue.GetAllGroups() do
		ProcessGroup(groupGUID)
	end
end
